{ pkgs ? import <nixpkgs> {} }:
with pkgs;

let
  registry = stdenv.mkDerivation {
    name = "dn42-registry";
    src = <registry>;
    phases = [ "unpackPhase" "patchPhase" "installPhase" ];
    nativeBuildInputs = [ python3 ];
    patchPhase = "patchShebangs utils";
    installPhase = "cp -ar . $out";
  };
  check = name: arg: stdenv.mkDerivation {
    inherit name;
    phases = [ "installPhase" "checkPhase" ];
    installPhase = "touch $out";
    buildInputs = [ python3 ];
    doCheck = true;
    checkPhase = ''
      cd ${registry}
      ./check-my-stuff ${arg}
    '';
  };
  mntners = builtins.attrNames (
    lib.filterAttrs (_: t: t == "regular") (
      builtins.readDir (<registry> + "/data/mntner")
    )
  );
  mntnerJobs = builtins.listToAttrs (
    map (mntner: rec {
      name = "mntner-${mntner}";
      value = lib.hydraJob (check name mntner);
    }) mntners
  );
in
mntnerJobs // {
  all = lib.hydraJob (check "all" "--all");
}
